/**
 * module WYSIWYG
 *
 * @author Evgueni V. Palchukovsky <epalchukovsky@swsoft.com>
 * @version $Id: modulewysiwyg.js,v 1.4 2006/02/13 05:17:06 epalchukovsky Exp $
 * @since 2006/01/20
 * @package SiteBuilder
 * @subpackage modules API
 * @copyright (c) 2004-2006, SWsoft
 */

///////////////////////////////////////////////////////////////////////////
// Globals:

var	_moduleWysiwyg = null;
var _formsActionsBackup = Array(document.forms.length);

///////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////
// Public objects contruction:
function GetModuleWysiwyg(	cmnPath,
							imgPath,
							incPath,
							css,
							imagesStorageDomain,
							imagesStorageHttpFolder) {
	if (!_moduleWysiwyg) {
		_moduleWysiwyg = new ModuleWysiwyg(
			cmnPath, imgPath, incPath, css,
			imagesStorageDomain, imagesStorageHttpFolder);
		if (!_moduleWysiwyg.IsReady()) {
			_moduleWysiwyg = null;
		}
	}
	return _moduleWysiwyg;
}

function GetModuleWysiwygEditor(cmnPath,
								imgPath,
								incPath,
								css,
								imagesStorageDomain,
								imagesStorageHttpFolder,
								id,
								moduleId) {
	var wysiwyg = GetModuleWysiwyg(
		cmnPath, imgPath, incPath, css,
		imagesStorageDomain, imagesStorageHttpFolder);
	return wysiwyg.PushBackNewEditor(id, moduleId);
}

///////////////////////////////////////////////////////////////////////////
// Classes:

function ModuleWysiwyg(	cmnPath,
						imgPath,
						incPath,
						css,
						imagesStorageDomain,
						imagesStorageHttpFolder) {

	///////////////////////////////////////////////////////////////////////////
	// Fields:

	this.m_ready = false;

	this.m_isGecko = null;
	this.m_isIe = null;

	this.m_pathCommon = cmnPath;
	this.m_pathImages = imgPath;
	this.m_pathIncludes = incPath;
	this.m_css = css;
	this.m_imagesStorageDomain = imagesStorageDomain;
	this.m_imagesStorageHttpFolder = imagesStorageHttpFolder;

	this.m_lang = "en";
	this.m_encoding = "UTF-8";

	this.m_oldActions = Array(document.forms.length);

	this.m_editors = Array();

	///////////////////////////////////////////////////////////////////////////

	///////////////////////////////////////////////////////////////////////////
	// Props:

	this.IsReady = function() {
		return this.m_ready;
	}
	this.IsGecko = function() {
		return this.m_isGecko;
	}
	this.IsIe = function() {
		return this.m_isIe;
	}
	this.GetCommonPath = function() {
		return this.m_pathCommon;
	}
	this.GetImagesPath = function() {
		return this.m_pathImages;
	}
	this.GetIncludesPath = function() {
		return this.m_pathIncludes;
	}
	this.GetCss = function() {
		return this.m_pathCss;
	}
	this.GetLanguage = function() {
		return this.m_lang;
	}
	this.GetEncoding = function() {
		return this.encoding;
	}
	this.GetEditor = function(id) {
		var result = this.m_editors[id];
		return result ? result : null;
	}
	this._SetEditor = function(obj) {
		this.m_editors[obj.GetId()] = obj;
	}

	this.GetImagesStorageDomain = function() {
		return this.m_imagesStorageDomain;
	}
	this.ImagesStorageHttpFolder = function() {
		return this.m_imagesStorageHttpFolder;
	}

	//////////////////////////////
	// Methods:

	this.PushBackNewEditor = function(id, moduleId) {
		result = false;
		if (this.IsReady()) {
			var obj = new ModuleWysiwygEditor(this, id, moduleId);
			this._SetEditor(obj);
			result = obj;
		}
		return result;
	}

	this.SubmitAll = function() {
		for (var i in this.m_editors) {
			var editor = this.GetEditor(i);
			if (!editor.Submit()) {
				result = false;
				break;
			}
		}
		return result;
	}

	///////////////////////////////////////////////////////////////////////////
	// Privates:

	this._CollectFormActions = function () {
		for (var i = 0; i<document.forms.length; ++i) {
			var f = document.forms[i];
			_formsActionsBackup[i] = f.getAttribute('action');
			f.setAttribute('action', "javascript: ModuleWysiwygPsevdoAction("+i+");");
		}
	}

	this._CheckBrowser = function() {
		var result = false;
		var userAgent_ = navigator.userAgent.toLowerCase();
		this.m_isIe =	((userAgent_.indexOf("msie")!=-1)
					&&	(userAgent_.indexOf("opera")==-1)
					&&	(userAgent_.indexOf("webtv")==-1));
		this.m_isGecko = (userAgent_.indexOf("gecko")!=-1);
		var isSafari = (userAgent_.indexOf("safari")!=-1);
		var isKonqueror = (userAgent_.indexOf("konqueror")!=-1);
		result = document.getElementById && document.designMode && !isSafari && !isKonqueror;
		if (this.IsIe()) {
			document.onmouseover = ModuleWysiwygIeButtonRaise;
			document.onmouseout = ModuleWysiwygIeButtonNormal;
			document.onmousedown = ModuleWysiwygIeButtonLower;
			document.onmouseup = ModuleWysiwygIeButtonRaise;
		}
		return true;
	}

	///////////////////////////////////////////////////////////////////////////
	// Construct:

	this.m_ready = this._CheckBrowser();
	if (this.IsReady()) {
		this._CollectFormActions();
	}

}
